clear
clear matrix

*set location of base_directory below:
local base_dir "C:\DataAppendix"

local in_dir "`base_dir'\data\raw"
local out_dir "`base_dir'\data"
local temp_dir "`base_dir'\temp"

*
* Format the NAFTA data
*


*append the csv files together and move out of the raw subfolder to main data folder
cd "`in_dir'\Bilateral_NAFTA\1988_base_year"
!copy *.csv NAFTA_88_07.csv
!move NAFTA_88_07.csv "`out_dir'"
cd "`out_dir'"


insheet using "`out_dir'\NAFTA_88_07.csv", comma clear names

drop if year == "Year"

replace commoditycode = commoditycode + "0" if length(commoditycode) == 4

destring, replace


rename tradeflowcode flow

gen importer = reportercode if flow == 1
replace importer = partnercode if flow == 2

gen exporter = reportercode if flow == 2
replace exporter = partnercode if flow == 1


rename commoditycode code
gen quantity = netweightkg
replace quantity = supplementaryquantity if quantity == .

keep year importer exporter code value quantity quantityunitcode netweightkg


*label data
label var importer Importer
label var exporter Exporter
label var code "SITC Commodity Code"

label define country 124 "Canada" 484 "Mexico" 842 "UnitedStates" 0 "World"
label values importer country
label values exporter country

label define qcodes 1 "no quantity" 2 "area in square meters" 3 "electrical energy in thousands of kilowatts" 4 "meters" 5 "number of items" 6 "number of pairs" 7 "volume in liters" 8 "weight in kilograms" 9 "thousands of items" 10 "number of packages" 11 "dozen of items" 12 "volume in cubic meters" 13 "weight in carats"

label values quantityunitcode qcodes

keep year importer exporter code value quantity quantityunitcode netweightkg

order exporter importer code year value quantity quantityunitcode netweightkg

save "`temp_dir'\temp", replace

*replace the data with Canada as an exporter from our old folder with the new Canadian export data - reported by Canada
use "`out_dir'\NAFTA", replace
drop if exporter == 124
append using "`temp_dir'\temp"


save "`out_dir'\NAFTA_88_07", replace

*delete the csv file
!del "`out_dir'\NAFTA_88_07.csv"