clear
clear matrix


*set location of base_directory below:
local base_dir "C:\DataAppendix"

local in_dir "`base_dir'\data"
local out_dir "`base_dir'\output"
local temp_dir "`base_dir'\temp"


*
* Least Traded Exercise
*

use "`in_dir'\NAFTA", replace


gen pair = string(exporter,"%03.0f") + "-" + string(importer,"%03.0f") + "-" + string(code,"%05.0f")

drop quantity quantityunitcode netweightkg

fillin pair year
replace value=0 if value==.
replace exporter = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9]"))
replace importer = real(regexs(1)) if(regexm(pair,".([0-9][0-9][0-9])"))
replace code = real(regexs(0)) if(regexm(pair,"[0-9][0-9][0-9][0-9][0-9]"))
drop _fillin

reshape wide value, i(pair) j(year)

gen pre_val = value1989

*right now I have the save post val for non-Can numbers
gen post_val = value2009

*drop the gas and elelectricity category goods or special transactions
drop if code == 34150
drop if code == 35100
drop if code == 93100

egen pre_val_avg = rowmean(value1989 value1990 value1991)

save "`temp_dir'\temp", replace

collapse (sum) pre_val, by(importer exporter)
rename pre_val pre_total

merge 1:m importer exporter using "`temp_dir'\temp"
drop _merge
save "`temp_dir'\temp", replace

sort importer exporter pre_val_avg

drop if pre_total==0
gen freq = pre_val/pre_total

by importer exporter, sort: gen cum_freq = sum(freq)

gen least=1 if cum_freq<0.10
replace least= (0.1-cum_freq[_n-1])*pre_total /pre_val if cum_freq >0.1 & cum_freq[_n-1]<0.1
replace least=0 if least==.


rename code sitc

keep importer exporter pre_val post_val least sitc

save "`temp_dir'\temp", replace


use "`temp_dir'\temp", replace

gen pre_least = least * pre_val
gen post_least = least * post_val

gen pre_most = pre_val - pre_least
gen post_most = post_val - post_least


collapse (sum) pre* post*, by (exporter importer)

save alt_est, replace

*
* add in the GDP data
*


insheet using "`in_dir'\raw\GDP_input.txt", clear

rename canada GDP124
rename unitedstates GDP842
rename mexico GDP484

reshape long GDP, i(year) j(exporter)

drop world

reshape wide GDP, i(exporter) j(year)

keep exporter GDP1989 GDP2009


merge 1:m exporter using alt_est
drop _merge


gen GDP_pre = GDP1989
gen GDP_post = GDP2009

gen alpha = 100 * (( (post_most / GDP_post) / (pre_most / GDP_pre) )-1)
gen beta = 100 * (( (post_least / GDP_post) / (pre_least / GDP_pre) )-1) - alpha

gen growth = alpha + .1 * beta

order exporter importer alpha beta growth


label values exporter country
sort exporter importer
format alpha beta %9.2f

save "`out_dir'\alphabeta_product_est", replace

keep exporter importer alpha beta
outsheet using "`out_dir'\tables\Table 9 Product Level.txt", names replace
